@@ -7,6 +7,7 @@ from classiq_interface.generator import result as generator_result
 from classiq_interface.server import routes
 
 from classiq._internals import api_wrapper, client
+from classiq._internals.type_validation import validate_type
 from classiq.exceptions import ClassiqAnalyzerError
 
 
@@ -19,6 +20,8 @@ class Analyzer:
         Args:
             circuit (): The circuit to be analyzed.
         """
+        if circuit.qasm is None:
+            raise ValueError("Analysis requires a circuit with valid QASM code")
         self._params = analysis_params.AnalysisParams(qasm=circuit.qasm)
 
     def analyze(self) -> analysis_result.Analysis:
@@ -41,10 +44,16 @@ class Analyzer:
 
         if result.status != analysis_result.AnalysisStatus.SUCCESS:
             raise ClassiqAnalyzerError(f"Analysis failed: {result.details}")
+        details = validate_type(
+            obj=result.details,
+            expected_type=analysis_result.Analysis,
+            operation="Analysis",
+            exception_type=ClassiqAnalyzerError,
+        )
 
         dashboard_path = routes.ANALYZER_DASHBOARD
         self.run_external_app(path=dashboard_path)
-        return result.details
+        return details
 
     @staticmethod
     def run_external_app(path: str) -> None:
