@@ -1,5 +1,5 @@
 import asyncio
-from typing import List, Optional
+from typing import Any, Dict, List, Optional
 
 from pyomo.core import ConcreteModel
 
@@ -19,6 +19,7 @@ from classiq_interface.generator import result as generator_result
 from classiq_interface.generator.result import GeneratedCircuit
 
 from classiq._internals.api_wrapper import ApiWrapper
+from classiq._internals.type_validation import validate_type
 from classiq.exceptions import (
     ClassiqError,
     ClassiqExecutionError,
@@ -38,7 +39,7 @@ class CombinatorialOptimization:
         self.is_maximization = sense.is_maximization(model)
         self._serialized_model = model_serializer.to_json(model, return_dict=True)
 
-        arguments = {
+        arguments: Dict[str, Any] = {
             "serialized_model": self._serialized_model,
             "encoding_type": encoding_type,
         }
@@ -64,7 +65,12 @@ class CombinatorialOptimization:
         if result.status != generator_result.GenerationStatus.SUCCESS:
             raise ClassiqGenerationError(f"Solving failed: {result.details}")
 
-        return result.details
+        return validate_type(
+            obj=result.details,
+            expected_type=GeneratedCircuit,
+            operation="Solving",
+            exception_type=ClassiqGenerationError,
+        )
 
     def solve(self) -> ExecutionData:
         return asyncio.run(self.solve_async())
@@ -78,7 +84,6 @@ class CombinatorialOptimization:
 
         if result.status != ExecutionStatus.SUCCESS:
             raise ClassiqExecutionError(f"Solving failed: {result.details}")
-
         return result.details
 
     def solve_classically(self) -> ExecutionData:
@@ -96,7 +101,7 @@ class CombinatorialOptimization:
 
         return result.details
 
-    def get_operator(self) -> operator.OperatorResult:
+    def get_operator(self) -> operator.PauliOperator:
         return asyncio.run(self.get_operator_async())
 
     async def get_operator_async(self) -> operator.PauliOperator:
@@ -108,8 +113,12 @@ class CombinatorialOptimization:
 
         if result.status != operator.OperatorStatus.SUCCESS:
             raise ClassiqError(f"Get operator failed: {result.details}")
-
-        return result.details
+        return validate_type(
+            obj=result.details,
+            expected_type=operator.PauliOperator,
+            operation="Get operator",
+            exception_type=ClassiqGenerationError,
+        )
 
     def get_objective(self) -> str:
         return asyncio.run(self.get_objective_async())
