@@ -6,7 +6,7 @@ _logger = logging.getLogger(__name__)
 class ClassiqError(Exception):
     def __init__(self, message: str) -> None:
         super().__init__(message)
-        _logger.error(f"{message}\n")
+        _logger.error("%s\n", message)
 
 
 class ClassiqExecutionError(ClassiqError):
@@ -41,9 +41,17 @@ class ClassiqQRegError(ClassiqValueError):
     pass
 
 
+class ClassiqQFuncError(ClassiqValueError):
+    pass
+
+
 class ClassiqAuthenticationError(ClassiqError):
     pass
 
 
 class ClassiqExpiredTokenError(ClassiqAuthenticationError):
     pass
+
+
+class ClassiqFileNotFoundError(FileNotFoundError):
+    pass
