@@ -17,6 +17,7 @@ from classiq_interface.executor.vqe_result import VQESolverResult
 from classiq_interface.generator import result as generation_result
 
 from classiq._internals import api_wrapper
+from classiq._internals.type_validation import validate_type
 from classiq.exceptions import ClassiqExecutionError
 
 
@@ -54,8 +55,12 @@ class Executor:
 
         if execution_result.status != exc_result.ExecutionStatus.SUCCESS:
             raise ClassiqExecutionError(f"Execution failed: {execution_result.details}")
-
-        return execution_result.details
+        return validate_type(
+            obj=execution_result.details,
+            expected_type=ExecutionDetails,
+            operation="Execution",
+            exception_type=ClassiqExecutionError,
+        )
 
     def execute_generated_circuit(
         self, generation_result: generation_result.GeneratedCircuit
@@ -82,8 +87,12 @@ class Executor:
 
         if execution_result.status != exc_result.ExecutionStatus.SUCCESS:
             raise ClassiqExecutionError(f"Execution failed: {execution_result.details}")
-
-        return execution_result.details
+        return validate_type(
+            obj=execution_result.details,
+            expected_type=(FinanceSimulationResults, GroverSimulationResults),
+            operation="Execution",
+            exception_type=ClassiqExecutionError,
+        )
 
     def execute_hamiltonian_minimization(
         self,
@@ -110,5 +119,9 @@ class Executor:
 
         if execution_result.status != exc_result.ExecutionStatus.SUCCESS:
             raise ClassiqExecutionError(f"Execution failed: {execution_result.details}")
-
-        return execution_result.details
+        return validate_type(
+            obj=execution_result.details,
+            expected_type=VQESolverResult,
+            operation="Execution",
+            exception_type=ClassiqExecutionError,
+        )
